/// <reference types="lodash" />
import { Op } from 'sharedb';
import { Operation, TargetOp } from './types/ot';
import { EngineInterface } from './types/engine';
import { HistoryInterface } from './types/history';
/**
 * 历史记录管理器
 */
declare class HistoryModel implements HistoryInterface {
    #private;
    private actionOps;
    private engine;
    private currentAction;
    private currentActionIndex;
    private remoteOps;
    private filterEvents;
    private selfEvents;
    constructor(engine: EngineInterface);
    /**
     * 懒保存当前操作
     */
    lazySave: import("lodash").DebouncedFunc<() => void>;
    /**
     * 重置所有操作
     */
    reset(): void;
    /**
     * 监听过滤事件
     * @param filter 事件
     */
    onFilter(filter: (op: Op) => boolean): void;
    /**
     * 监听收集本地操作事件
     * @param event 事件
     */
    onSelf(event: (ops: Op[]) => Promise<boolean> | boolean | undefined): void;
    /**
     * 是否有撤销操作
     * @returns boolean
     */
    hasUndo(): boolean;
    /**
     * 是否有重做操作
     * @returns boolean
     */
    hasRedo(): boolean;
    /**
     * 执行撤销操作
     */
    undo(): void;
    /**
     * 执行重做操作
     */
    redo(): void;
    /**
     * 清空所有历史操作
     */
    clear(): void;
    saveOp(): void;
    handleSelfOps(ops: Op[]): void;
    handlePath: <T extends any[] | readonly any[]>(path: T, id: string, bi: number, isOp?: boolean, filter?: (node: Node) => boolean) => T;
    handleRemoteOps(ops: TargetOp[]): void;
    getUndoOp(): Operation | undefined;
    getRedoOp(): Operation | undefined;
    getCurrentRangePath(): {
        start: import("./types").RangePath;
        end: import("./types").RangePath;
    } | undefined;
    getRangePathBeforeCommand(): {
        start: import("./types").RangePath;
        end: import("./types").RangePath;
    } | undefined;
}
export default HistoryModel;
