import { EditorInterface, NodeInterface, RangeInterface } from '../types';
import { MarkInterface, MarkModelInterface } from '../types/mark';
declare class Mark implements MarkModelInterface {
    private editor;
    constructor(editor: EditorInterface);
    init(): void;
    /**
     * 解析markdown
     * @param event 事件
     */
    triggerMarkdown(event: KeyboardEvent): boolean | undefined;
    /**
     * 根据节点查找mark插件实例
     * @param node 节点
     */
    findPlugin(mark: NodeInterface): MarkInterface | undefined;
    /**
     * 获取最近的 Mark 节点，找不到返回 node
     */
    closest(source: NodeInterface): NodeInterface;
    /**
     * 获取向上第一个非 Mark 节点
     */
    closestNotMark(node: NodeInterface): NodeInterface;
    /**
     * 比较两个节点是否相同，包括attributes、style、class
     * @param source 源节点
     * @param target 目标节点
     * @param isCompareValue 是否比较每项属性的值
     */
    compare(source: NodeInterface, target: NodeInterface, isCompareValue?: boolean): boolean;
    /**
     * 判断源节点是否包含目标节点的所有属性名称和样式名称
     * @param source 源节点
     * @param target 目标节点
     */
    contain(source: NodeInterface, target: NodeInterface): boolean;
    /**
     * 去除一个节点下的所有空 Mark，通过 callback 可以设置其它条件
     * @param root 节点
     * @param callback 回调
     */
    unwrapEmptyMarks(root: NodeInterface, callback?: (node: NodeInterface) => boolean): void;
    /**
     * 在光标重叠位置时分割，在分割时会清空父节点内容再重组，如果需要保持光标右边某节点的追踪，请传入该节点
     * @param range 光标
     * @param removeMark 要移除的mark空节点
     * @param keelpNode 分割光标右侧需要保持追踪的节点
     */
    splitOnCollapsed(range: RangeInterface, removeMark?: NodeInterface | Array<NodeInterface>, keelpNode?: NodeInterface | Node): NodeInterface | Node | undefined;
    /**
     * 在光标位置不重合时分割
     * @param range 光标
     * @param removeMark 要移除的空mark节点
     */
    splitOnExpanded(range: RangeInterface, removeMark?: NodeInterface | Array<NodeInterface>): void;
    /**
     * 分割mark标签
     * @param removeMark 需要移除的mark标签
     */
    split(range?: RangeInterface, removeMark?: NodeInterface | Node | string | Array<NodeInterface>): void;
    /**
     * 在当前光标选区包裹mark标签
     * @param mark mark标签
     * @param both mark标签两侧节点
     */
    wrap(mark: NodeInterface | Node | string, range?: RangeInterface): void;
    mergeMarks(marks: Array<NodeInterface>): void;
    /**
     * 合并当前选区的mark节点
     * @param range 光标，默认当前选区光标
     */
    merge(range?: RangeInterface): void;
    /**
     * 去掉mark包裹
     * @param range 光标
     * @param removeMark 要移除的mark标签
     */
    unwrap(removeMark?: NodeInterface | Node | string | Array<NodeInterface>, range?: RangeInterface): void;
    /**
     * 光标处插入mark标签
     * @param mark mark标签
     * @param range 指定光标，默认为编辑器选中的光标
     */
    insert(mark: NodeInterface | Node | string, range?: RangeInterface): void;
    /**
     * 查找对范围有效果的所有 Mark
     * @param range 范围
     */
    findMarks(range: RangeInterface): NodeInterface[];
    /**
     * 从下开始往上遍历删除空 Mark，当遇到空 Block，添加 BR 标签
     * @param node 节点
     * @param addBr 是否添加br
     */
    removeEmptyMarks(node: NodeInterface, addBr?: boolean): void;
    repairCursor(mark: NodeInterface | Node): void;
}
export default Mark;
